SessionOpsBuf

Struct SessionOpsBuf 

pub struct SessionOpsBuf(Vec<u8>);
Available on crate feature alloc only.
A heap-backed, owned buffer of encoded SessionOps.

Dereferences to SessionOps so iteration, application and decoding are available without copying.

Tuple Fields

0: Vec<u8>

Implementations



impl SessionOpsBuf

pub const fn new() -> Self

Creates an empty operations buffer.

pub fn push(&mut self, op: &SessionOp<'_>)

Encodes and append an operation to this buffer.

pub const fn as_bytes(&self) -> &[u8]

Returns the raw encoded bytes accumulated so far.

pub const fn as_session_ops(&self) -> &SessionOps

View this buffer as a borrowed SessionOps slice.

pub const fn is_empty(&self) -> bool

Returns true if no operations have been buffered.

pub fn clear(&mut self)

Discard all buffered operations.

Methods from Deref<Target = SessionOps>

pub fn as_bytes(&self) -> &[u8]

Returns the raw encoded bytes backing this slice.

pub fn is_empty(&self) -> bool

Returns true if there are no operations.

pub fn iter(&self) -> SessionOpsIter<'_>

Returns an iterator over the operations in this buffer.

pub fn apply<S: SessionState>(&self, session: &mut S)

Apply every operation in this buffer to session, in order.